FloatToFixed

Trait FloatToFixed 

pub trait FloatToFixed: Sealed { }
A floating point number that can be written into a ryu_js::Buffer using the fixed notation as defined in the Number.prototype.toFixed( fractionDigits ) ECMAScript specification.

This trait is sealed and cannot be implemented for types outside of the ryu-js crate.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl FloatToFixed for f64

Implementors